@@ -4,7 +4,10 @@ import pathlib
 
 class _ChadwickLibrary:
     library_path = (
-        pathlib.Path(__file__).absolute().parent.parent / "lib" / "cwevent" / "libcwevent.so"
+        pathlib.Path(__file__).absolute().parent.parent
+        / "lib"
+        / "cwevent"
+        / "libcwevent.so"
     )
 
     def __init__(self):
@@ -15,4 +18,3 @@ class _ChadwickLibrary:
         if self._dll is None:
             self._dll = ctypes.cdll.LoadLibrary(self.library_path)
         return self._dll
-
